pub struct DMSCTracer { /* private fields */ }Expand description
Distributed tracer
Implementations
Sourceimpl DMSCTracer
impl DMSCTracer
pub fn new(sampling_rate: f64) -> Self
Sourcepub fn with_strategy(strategy: DMSCSamplingStrategy) -> Self
pub fn with_strategy(strategy: DMSCSamplingStrategy) -> Self
Create a new tracer with a custom sampling strategy
Sourcepub fn start_trace(&self, name: String) -> Option<DMSCTraceId>
pub fn start_trace(&self, name: String) -> Option<DMSCTraceId>
Start a new trace and set it as current context
Sourcepub fn start_span(
&self,
trace_id: Option<&DMSCTraceId>,
parent_span_id: Option<DMSCSpanId>,
name: String,
kind: DMSCSpanKind,
) -> Option<DMSCSpanId>
pub fn start_span( &self, trace_id: Option<&DMSCTraceId>, parent_span_id: Option<DMSCSpanId>, name: String, kind: DMSCSpanKind, ) -> Option<DMSCSpanId>
Start a new span in existing trace, using current context if available
Sourcepub fn start_span_from_context(
&self,
name: String,
kind: DMSCSpanKind,
) -> Option<DMSCSpanId>
pub fn start_span_from_context( &self, name: String, kind: DMSCSpanKind, ) -> Option<DMSCSpanId>
Start a new span using current context
Sourcepub fn end_span(
&self,
span_id: &DMSCSpanId,
status: DMSCSpanStatus,
) -> DMSCResult<()>
pub fn end_span( &self, span_id: &DMSCSpanId, status: DMSCSpanStatus, ) -> DMSCResult<()>
End a span and restore parent span context if available
Sourcepub fn span_mut<F>(&self, span_id: &DMSCSpanId, f: F) -> DMSCResult<()>
pub fn span_mut<F>(&self, span_id: &DMSCSpanId, f: F) -> DMSCResult<()>
Get span for modification
Sourcepub fn export_traces(&self) -> HashMap<DMSCTraceId, Vec<DMSCSpan>>
pub fn export_traces(&self) -> HashMap<DMSCTraceId, Vec<DMSCSpan>>
Export completed traces
Sourcepub fn active_trace_count(&self) -> usize
pub fn active_trace_count(&self) -> usize
Get active traces count
Sourcepub fn active_span_count(&self) -> usize
pub fn active_span_count(&self) -> usize
Get active span count